
% Texto a la derechas de un "%" es un comentario y Matlab no lo considera
% Recuerde que puede acceder a la ayuda de Matlab presionando F1 o usando el
% comando "help" seguido del nombre de un comando

% Operaciones bsicas

a = 5
b = 5 + 4*j
a+b
abs(a+b)
angle(a+b)
c = a+b

whos

c^(0.8282828)
sqrt(c)

clc

% Resolver ecuaciones lineales Ax=b

A = [ 1 3; 9 0]
detA = det(A)

b = [ -1; 9]
x = A\b

% Extraer filas, columnas y porciones de matrices

A
A(1,1)
A(1, :)
A(:, 2)

A = rand(10,10)
A(2:5, 6:8)

clc

% Graficos 

t = [0:0.01:2];  % OJO con el ";" (evita que Matlab muestre el resultado de ejecutar un comando)
plot( t, 3*sin(2*pi*1*t) )
figure(2), plot( t, 0.3*sin(2*pi*1*t) )  % Se crea la figura 2 si es que no existe, 
                                         % o se indica que los plots siguientes van a dibujarse en la figura 2 si es que sta ya exista
figure(1), hold on, plot(t, exp(-2*t) + 1) % se retorna a la figura inicial.  "hold on" permite superponer graficas.
legend('Sinusoide' , 'exponencial')

clc

% Uso de archivos .m para ejecutar secuencias de comandos (edite "ejemplo.m")

ejemplo

% Operadores ".X" (donde X es un operador estndar)
t= [0 1 2];
t-1
t*t  % Note que esto produce un error pues no se pueden multiplicar dos matrices de 1x3 entre s
t.*t % esto multiplica t por t elemento a elemento.

% Funciones en matlab (son archivos .m, pero empiezan con el comando "function".  Edite "mi_fun.m")

mi_fun(8.9)
t= [0 1 2];
mi_fun(t)

x = [-2:0.02:2];
plot(x, mi_fun(x))
grid on

% Solucion de ecuaciones y minimizacin en un intervalo (apyese en el grfico anterior)

sol = fzero( @mi_fun, 0.28)
sol = fzero( @mi_fun, 1)
sol = fzero( @mi_fun, 100)
sol = fzero( @mi_fun, [0.6 1.4])
sol = fzero( @mi_fun, [-1.4 -1])  % esto produce error, pues no hay raz entre -1.4 y -1

[xmin, min] = fminbnd(@mi_fun, 0.9, 1.9)

% Integracin numrica

int = quad( @mi_fun, -1, 1)

% Funciones de transferencia y anlisis de sistemas lineales

close all % cierra todas las figuras

H = tf([1 2], [ 1 7 12 ])
H = zpk(H)

H1 = tf([1 2], poly([-3 -4]) )
H2= tf(1, [1 -2])

H3 = H1+H2 % OPeraciones bsicas con funciones de transferencias
H4 = H1*H2
H5 = H1^3

pole(H) % polos y ceros
zero(H)
zpk(H)  % factorizaciones

roots([1 3 3 2]) % races de polinomios (en este caso es polinomio 1s^3 + 3s^2 + 3s + 2).

step(H, H2)  % respuesta a escaln (vea tb. step(H, H2, 100), en que 100 se refuiere al tiempo final)
impulse(H, 2) % respuesta a impulso
bode(H) % diagrama de Bode
evalfr(H, 0) % evaluar funcin de transferencia en s=0 (respuesta en frecuancia a frecuencia w=0)
evalfr(H, 2*j) % evaluar funcin de transferencia en s=2*j (respuesta en frecuancia a frecuencia w=2)

t = [0:0.01:10];
u = 0.4 * sin(2*t);
y = lsim( H, u, t); % salida de sistema H, cuando la entrada es u y el vector de tiempo es t 
                    % (lsim supone condiciones iniciales cero, a menos que se trabaje en variables 
                    % de estado, en cuyo caso se pueden fijar arbitrariamente)
plot(t,u,'r', t, y, 'b'), grid on, legend('entrada', 'salida')

% Trabajo simblico
clc 
syms s t A B % define vars simblicas

f = A + B*sin(4*t) + exp(-3*t) % crea funcin 

F = laplace(f)    % laplace y laplace inverso (si aparecen funciones hiperblicas, use comando "simple")
pretty(laplace(f))
f2 = ilaplace( 1/s + (s^3+s+1)/(s^4+3*s+2*s^2) )
pretty(f2)

% Solucin analtica de ecuaciones

syms s L iL R1 i R2 C
e1 = L*s*iL + R1*(iL+i) - 1/s;  % definicin de las ecuaciones a resolver (igualadas a cero)
e2 = R2*i + 1/s - 1/s  + i/(s*C) + R1*(iL+i)
sol = solve(e1, e2, iL, i)    % solucin de las ecs e1 y e2, con incnitas iL e i 
sol.i

I = subs(sol.i, {R1, R2, C, L}, {2, 22/21, 21/16, 1/4})  % reemplazo valores numricos
